@@ -47,11 +47,16 @@ from data_science_helper.model import custom_bagging__lgb_model as cb_lgb_model
 
 def modelar_clasificacion_binaria(strategy="", X_train=None,y_train=None,X_test=None,y_test=None,params=None,metric='average_precision',num_rounds=10000,early_stop=400,log=0,api="train_api",random_state=42,url=None,print_consola=True):
     start = time.time()
+        
+    params.update({"metric":metric})
+    params.update({"seed":random_state})
+    params.update({"objective":'binary'})
             
     args = {'X_train':X_train, 'y_train': y_train, 'X_test': X_test, 'y_test': y_test, 'params':params,
-            "metric":metric,"num_rounds":num_rounds,"early_stop":early_stop,"log":log,"api":api ,
-            "random_state":random_state, url:"url" }  
+            "metric":metric,"num_rounds":num_rounds,"early_stop":early_stop,"log":log,"random_state":random_state,"api":api ,
+            "url":url }     
     
+
     
     if (strategy=="neg_bagging_fraction__lgb_model"):
         model , y_prob_uno   = nbf_lgb_model.modelar(**args)
